import React, { useEffect, useState } from "react";
import { retrieveData } from "./service";
import './autocomplete.css'
import TextField from "@mui/material/TextField";
import Autocomplete from "@mui/material/Autocomplete";
import CircularProgress from "@mui/material/CircularProgress";

export const ReactBatchAutocomplete = ({
  placeholder = "Enter your address",
  notFoundText = "Not found data",
  onSelect,
  suggestionList,
  handleError,
  apiKey,
  domainServer
}) => {
  const [search, setSearch] = useState("");
  const [searchQuery, setSearchQuery] = useState("");
  const [open, setOpen] = useState(false);
  const [options, setOptions] = useState([]);
  const [loading, setLoading] = useState(false);
  
  useEffect(() => {
    const timeout = setTimeout(() => {
      setSearchQuery(search);
    }, 700);

    return () => {
      clearTimeout(timeout);
    };
  }, [search]);

  useEffect(async () => {
    if (searchQuery?.trim().length > 2 && options?.filter((item) => item.name === searchQuery)?.length === 0) {
      try {
        setLoading(true);
        setOpen(false);
        let data = await retrieveData(apiKey, domainServer, searchQuery);
        if (data?.status?.code !== 200) {
          handleError?.(data?.status);
        } else {
          setOptions(data?.result?.suggestions);
          suggestionList?.(data?.result?.suggestions);
          setOpen(true);
        }
        setLoading(false);
      } catch (e) {
        handleError?.(e);
        setLoading(false);
      }
    } else {
      setOptions([]);
    }
  }, [searchQuery]);
  return (
    <div className="autocomplete-wrapper">
    <Autocomplete
      disablePortal
      className="custom-autocomplete"
      open={open}
      onOpen={() => {
        search.length > 2 && setOpen(true);
      }}
      onClose={() => {
        setOpen(false);
      }}
      classes={{paper: "test"}}
      onInputChange={(event, value) => {
        setSearch(value);
      }}
      getOptionLabel={(option) => option.name}
      onChange={(event, data) => onSelect?.(data)}
      inputValue={search}
      options={options}
      noOptionsText={notFoundText}
      clearOnBlur={false}
      renderInput={(params) => (
        <TextField
          {...params}
          hiddenLabel
          placeholder={placeholder}
          id="filled-hidden-label-normal"
          InputProps={{
            ...params.InputProps,
            endAdornment: (
              <>
                {loading ? (
                  <CircularProgress className="spinner" size={20} />
                ) : null}
                {params.InputProps.endAdornment}
              </>
            ),
          }}
        />
      )}
      renderOption={(props, option) => {
        let name = option.name;
        return (
          <div {...props}>
            <div className="auto-wrapper">
              <div className="img-wrap" />
              <div className="text-content">
                <strong>{name.substr(0, search.length)}</strong>
                {name.substr(search.length)}
              </div>
            </div>
          </div>
        );
      }}
    />
    </div>
  );
};